pub struct DcdFrame {
pub time: f64,
pub atom_posits: Vec<Vec3>,
pub unit_cell: DcdUnitCell,
}Fields
time: f64fs
atom_posits: Vec<Vec3>Å
unit_cell: DcdUnitCellAlso called Periodic box. This is often the bounds of the simulation, with solvents wrapping around periodic boundary conditions, and long-range forces computed across this.