pub struct OutputControl {
pub nstxout: Option<u32>,
pub nstvout: Option<u32>,
pub nstfout: Option<u32>,
pub nstlog: Option<u32>,
pub nstcalcenergy: Option<u32>,
pub nstenergy: Option<u32>,
pub nstxout_compressed: Option<u32>,
pub compressed_x_precision: u32,
}Fields
nstxout: Option<u32>Write full-precision coordinates to .trr every N steps (0 = never).
nstvout: Option<u32>Write velocities to .trr every N steps (0 = never).
nstfout: Option<u32>Number of steps that elapse between writing forces to the output trajectory file
nstlog: Option<u32>Write to .log every N steps.
nstcalcenergy: Option<u32>Calculate energies to .edr every N steps.
nstenergy: Option<u32>Write energies to .edr every N steps.
nstxout_compressed: Option<u32>Write compressed coordinates to .xtc.rs every N steps (0 = never).
compressed_x_precision: u32precision with which to write to the compressed trajectory file
Implementations